@@ -62,7 +62,7 @@ class QuentaAdmin(ModelAdmin):
 
 
 class PackageAdmin(ModelAdmin):
-    list_display = ('name', 'version', 'title', 'location', 'is_default')
+    list_display = ('name', 'title', 'location', 'is_default')
     list_filter = ('is_default',)
 
 
