@@ -1,6 +1,6 @@
 import os
 from functools import wraps
-from typing import Callable, Any
+from typing import Callable
 
 from django.http import HttpRequest, HttpResponseForbidden, HttpResponse
 from pydantic import BaseModel
@@ -21,8 +21,9 @@ def authenticated(func: Callable[[Player, HttpRequest], BaseModel]):
         if not all((access_header, client_header)):
             raise HttpResponseForbidden
 
-        player: Player = Player.objects.get(token__access=access_token, token__client=client_token)
-        if player is None:
+        try:
+            player: Player = Player.objects.get(token__access=access_token, token__client=client_token)
+        except (Player.DoesNotExist, Player.MultipleObjectsReturned):
             raise HttpResponseForbidden
 
         response = func(player, request)
